/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2019 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_cg_timer_user.c
* Version      : CodeGenerator for RL78/G12 V2.04.04.02 [20 Nov 2019]
* Device(s)    : R5F10266
* Tool-Chain   : CCRL
* Description  : This file implements device driver for TAU module.
* Creation Date: 2020/10/16
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_timer.h"
/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
#pragma interrupt r_tau0_channel0_interrupt(vect=INTTM00)
#pragma interrupt r_tau0_channel1_interrupt(vect=INTTM01)
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
#define LIMIT_DUTY ( 90 )               /* max duty ratio is 90%                */
#define START_DUTY ( 10 )               /* start duty ratio is 10%              */
#define DUTY_STEP  ( 10 )               /* duty increase step is 10%            */

#define DEBUG

#ifdef DEBUG

uint16_t data_list[10];
uint8_t count = 0;
#endif

volatile uint8_t g_duty_ratio = START_DUTY; /* duty ration of PWM (%)           */
uint16_t r_set_duty( uint8_t );         /* get next TDR data of specified duty  */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: r_tau0_channel0_interrupt
* Description  : This function is INTTM00 interrupt service routine.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
static void __near r_tau0_channel0_interrupt(void)
{
    /* Start user code. Do not edit comment generated here */
    static uint8_t tm00_count = 0U;    /* INTTM00 interrupt times counter */

    if ((++tm00_count) == 250)        /* Update the duty factor per 500ms */
    {
        tm00_count = 0U;                /* Interrupt counter reset */
        P1 ^= 0b00000001;               /* Invert LED2 */

#ifdef DEBUG
        data_list[count++] = TDR01;     /* for check TDR change     */
        if ( count >= 10 )
        {
            count = 0;
        }
        
#endif

        g_duty_ratio += DUTY_STEP;      /* get next duty ratio              */

        if (g_duty_ratio > LIMIT_DUTY)  /* check limit over or not          */
        {                               /* If next duty over 90%,           */
            g_duty_ratio = START_DUTY;  /* Set duty factor to 10%           */
        }
        else
        {
            ;
        }

        TDR01 = r_set_duty( g_duty_ratio ); /* set next active period data  */

    }
    else
    {
        ;
    }
    /* End user code. Do not edit comment generated here */
}

/***********************************************************************************************************************
* Function Name: r_tau0_channel1_interrupt
* Description  : This function is INTTM01 interrupt service routine.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
static void __near r_tau0_channel1_interrupt(void)
{
    /* Start user code. Do not edit comment generated here */
    /* End user code. Do not edit comment generated here */
}

/* Start user code for adding. Do not edit comment generated here */
/********************************************************************************
* Function Name: r_set_duty
* Description  : This function calculate TDR data from specified duty ratio.
* Arguments    : duty ratio(%)
* Return Value : TDR value
********************************************************************************/
uint16_t r_set_duty( uint8_t duty )
{
    uint16_t data_work1;
    uint32_t data_work2;
    uint8_t  duty_work;

    if ( 100 < duty )                   /* check duty ratio             */
    {
        duty_work = 100;                /* set limit is 100%            */
    }
    else
    {
        duty_work = duty;
    }

    data_work1 = ( TDR00 +1 );          /* get period of PWM            */
    data_work2 = ( ( data_work1 * 1UL ) * duty_work );

    return((data_work2 / 100));         /* get set value                */

}
/* End user code. Do not edit comment generated here */
